@@ -1,6 +1,9 @@
 import os
 
-"""Used for importing settings, and defining default settings"""
+# Used for importing settings, and defining default settings
+#
+# Override per project settings in pyroutes_settings.py in
+# your project folder
 
 # Default template dir, relative to this imported __file__
 BUILTIN_TEMPLATES_DIR = os.path.join(
@@ -21,6 +24,12 @@ SECRET_KEY = 'asdfnaj2308sydfahli37flas36al9gaiufw'
 # Location for templates. Used by TemplateRenderer
 TEMPLATE_DIR = None # /foo/bar/templates/
 
+# Middleware
+MIDDLEWARE = [
+    'pyroutes.middleware.errors.NotFoundMiddleware',
+    'pyroutes.middleware.errors.ErrorHandlerMiddleware',
+]
+
 # Attempt to get custom settings. Not obligatory.
 try:
     from pyroutes_settings import *
